Developers

Note

These APIs are subject to change at any time and are for internal use only.

Agreement

This endpoint allows users to accept the developer agreement.

POST /api/v5/developers/agreement
Request JSON Object:
  • display_name (string|null) – User’s chosen display name. Required if the user doesn’t have a display name yet. Errors if they already have one.

  • last_developer_agreement_change (string) – The date of the last agreement change.

GET /api/v5/developers/agreement
Response JSON Object:
  • display_name (string|null) – The user’s display name, if set.

  • has_read_developer_agreement (boolean) – Whether the user has agreed to the latest agreement.

  • last_developer_agreement_change (string) – The date of the last agreement change.

Support

This endpoint allows users to submit a support ticket to AMO. Echoes the submitted data on success.

POST /api/v5/developers/support
Response JSON Object:
  • summary (string) – Issue summary.

  • body (string) – Details about the issue.

  • category (string) – Issue category. Can be policy, technical, or other.